@@ -1,18 +1,8 @@
-/***************************************************************************
-
-    Copyright 2006, 2007 Peter Hedlund <peter.hedlund@kdemail.net>
-    Copyright 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006, 2007 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-FileCopyrightText: 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "vocabularydelegate.h"
 #include "vocabularymodel.h"
@@ -20,7 +10,6 @@
 
 #include "prefs.h"
 #include "languagesettings.h"
-#include "readonlycontainermodel.h"
 
 #include <KEduVocExpression>
 #include <KEduVocWordtype>
