@@ -1,17 +1,7 @@
-/***************************************************************************
-
-    Copyright 2008 Avgoustinos Kadis <avgoustinos.kadis@kdemail.net>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Avgoustinos Kadis <avgoustinos.kadis@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "parley.h"
 
@@ -22,12 +12,10 @@
 #include "../scriptmanager.h"
 #include "../translator.h"
 
-#include "document.h"
 #include "lesson.h"
 #include "expression.h"
 #include "translation.h"
 
-#include <QDebug>
 #include <KActionCollection>
 #include <QMenuBar>
 
